package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0D```````````(``P`!````L)L$"#0```!DLP```````#0`(``'
M`"@`'``;``8````T````-(`$"#2`!`C@````X`````4````$`````P```!0!
M```4@00(%($$"`T````-````!`````$````!``````````"`!`@`@`0(\*H`
M`/"J```%`````!````$`````L````#`%"``P!0AH`@``\`8```8`````$```
M`@```!2P```4,`4(%#`%"/@```#X````!@````0````$````)`$``"2!!`@D
M@00(1````$0````$````!````%'E=&0```````````````````````````8`
M```$````+VQI8B]L9"YS;RXQ``````0````0`````0```$=.50`#````!@``
M````````````!````!0````#````1TY5`#U>34S,L\S/LQ>670X:"PZAFZ\3
M80```'$````*```````````````]`````````$8```!%`````````#,````F
M````.P```#8````/````-P```%8`````````+@```%\```!2````:````&H`
M``!0````.@```",``````````````!(```!)````*P``````````````9```
M`&\````E````"0```&T```!/````<````!8```!+``````````<`````````
M;@````````!.````/@``````````````9@```"<```!-````&P``````````
M````60```#$````+````0P``````````````1``````````\````````````
M```>``````````0````_````0@```$````!G````40``````````````6P``
M`&D````X````&````$H````!````,``````````,````````````````````
M4P```&(`````````00```%X````M````.0```#0````0````````````````
M````````````````````````````````````````````````````3```````
M```````````````````````````````````````````````````.````70``
M```````4``````````````````````````,``````````````%0`````````
M`````&4```!:`````````````````````````!$````<````````````````
M````(0````@````J`````````%4````B````#0````````!A````+P``````
M````````&0```"@```!K````&@````8``````````````!\````3````*0``
M``````!<````1P```&,```!(````!0``````````````````````````````
M````````````````6````!T```````````````````!L````````````````
M````````````````````5P``````````````8``````````7`````````!4`
M```@```````````````D`````@`````````L````,@```#4````E````3```
M``@````(`````!`0!"5`!(*H`0`!HH8!J$````)/*`0I.*(R1XJ$#`A,````
M3@```````````````````%````!2````4P```%0```!5````5@```%<```!8
M````6@```%L`````````7````````````````````%T```!@````````````
M``!A````8P```&0```!F`````````&<```!I``````````````!K````;```
M`&X`````````R-6R<5GH[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XY[G[U][
MA_F<@6L)0]8Y\HL<##J7"T>8!<;%B060#13BGB'_Y`[$N9Q`L@&+;VM_FGQ_
MJ9R;;L7?']EQ6!R[XY)\U&34?*U+X\`S8MOM9J_,9GOP2FOB1\8!0T75['U!
MCL7"Y3\LH2(+(/+;TQWZH6Q@N8WQ#@````````````````````#\`P``````
M```````2````L0``````````````$@```)(!`````````````!(```"7`0``
M```````````2````:P(`````````````$@```/(#`````````````!(````$
M!``````````````2````$0``````````````(````"```````````````"``
M``!^`0`````````````2````<@,`````````````$@```%\!````````````
M`!(```!Q`0`````````````2````$P,`````````````$@```"4#````````
M`````!(```#<`@`````````````2````'0(`````````````$@```&4#````
M`````````!(```#]```````````````2````#0(`````````````$@```(@#
M`````````````!(````J`P`````````````2````NP$`````````````$@``
M`,L$`````````````!(```")`@`````````````2````VP$`````````````
M$@```"8"`````````````!(````O`0`````````````2````-```````````
M````$@```,<#`````````````!(```""`@`````````````2````Z@,`````
M````````$@```$X!`````````````!(```#(```````````````2````S0(`
M````````````$@```($#`````````````!(```"/`P`````````````2````
M\P(`````````````$@```.,#`````````````!(````R`P`````````````2
M````30(`````````````$@```-P#`````````````!(```"J`P``````````
M```2````R`(`````````````$@```-4"`````````````!(````_`@``````
M```````2````M0,`````````````$@```)P!`````````````!(```!4`P``
M```````````2````"P0`````````````$@```#H#`````````````!(```"C
M`P`````````````2````[```````````````$@```$(``````````````!(`
M``!Z`P`````````````2````UP``````````````$@```.\!````````````
M`!(```!L`P`````````````2````=@(`````````````$@```$$!````````
M`````!(````=`0`````````````2````0P,`````````````$@```.T"````
M`````````!(```"6`P`````````````2````-`(`````````````$@```+T#
M`````````````!(```!4```````````````2````3`,`````````````$@``
M`,D!`````````````!(```!C```````````````2````CP``````````````
M$@```)T#`````````````!(````2!``````````````2````>```````````
M````$@````L!`````````````!(```"H`0``3)<$"``````2````@@0``,#+
M!`@$````$0`0`%@%``"PN@0(HPH``!(`#@"$!0``$+,$")4!```2``X`?`0`
M`)S+!`@`````$@`/`"8$``"`,@4(!````"$`&0!4!```<)P$"`<````2``X`
M!`4``!#+!`A:````$@`.`!D%````SP0(ZEL``!$`$`"@````[)@$"``````2
M````[P0``%0R!0@`````$``8`-4#``"$,@4(!````!$`&0#Q!```5#(%"```
M```@`!@`%`4``&`R!0@$````$0`8`"4$``"`,@4(!````"$`&0!R!````,L$
M"`4````2``X`=P4``)"X!`@1`@``$@`.`"0$``"`,@4(!````!$`&0"?!```
M<*H$"$0````2``X`'P0``'"V!`@@`@``$@`.`+D$``"PM`0('P```!(`#@#4
M!```X+4$"(8````2``X`0P0``&@R!0@`````$`#Q_T\$``#P-@4(`````!``
M\?^)!```8,4$")L$```2``X`X`0``,3+!`@$````$0`0`/4$``"PFP0(````
M`!(`#@"M!```T+0$"!`!```2``X`6P(``-R8!`@`````$@```&4$``"`G`0(
M/@```!(`#@`\!```:#(%"``````0`/'_*`4```"K!`A<````$@`.`/P$````
MR@0(/@```!(`#@!$!0``9#(%"`0````1`!@`E`(``(@R!0@3````$0`9`&4%
M``#PL00(&`$``!(`#@#^!```G)8$"``````2``P``&QI8G!E<FPN<V\N-2XQ
M,`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES
M7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI=#,`4&5R;%])
M97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7TEC
M;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R<W1A8VMI;F9O
M7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L
M7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`
M4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]N97=3
M5G!V`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]):6Y?979A;%]P='(`4&5R;%])
M;W!?<'1R`%!E<FQ?265V86Q?<F]O=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H
M<E]K97E?<'1R`%!E<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%])<&5R;%]D97-T
M<G5C=%]L979E;%]P='(`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T
M8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L
M;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M
M+G-O+C$`;&EB<'1H<F5A9"YS;RXP`')E860`;'-E96LV-`!O<&5N-C0`7U]E
M<G)N;U]L;V-A=&EO;@!C;&]S90!P=&AR96%D7V=E='-P96-I9FEC`&QI8F,N
M<V\N,"XQ`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W!R:6YT9@!S=')N8VUP
M`%]?<W1R9'5P`&-L;W-E9&ER`'-T<FYC<'D`7U]S=&%C:U]C:&M?9F%I;`!U
M;FQI;FL`;6MD:7(`<F5A;&QO8P!G971P:60`<W1R=&]K`'-T<FQE;@!M96US
M970`<W1R<W1R`')M9&ER`&UE;6-P>0!?7VQX<W1A=#8T`&]P96YD:7(`7U]X
M<W1A=#8T`%]?8W1Y<&5?8E]L;V,`<W1D97)R`&=E='5I9`!E>&5C=G``9G!R
M:6YT9@!R96%D9&ER-C0`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S
M=&%R=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?
M;&EB8U]C<W5?9FEN:0!?9G!?:'<`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A
M<E]E;G9?8VQE86X`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T
M`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`&YA;65?;&]A9%]M>5]P87)?<&P`
M6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`'-I>F5?;&]A9%]M>5]P87)?
M<&P`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O
M9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS`$=,24)#7S(N-`!'3$E"0U\R+C,N
M,@`````"```````"`````@`"``````````(```````,``@`$`````@``````
M`@`"`````@```````````````@`"``(```````0``@`"``0``@`"`````@`"
M``0`!`````(````%``(``@`"```````"```````"``````````(`!``"````
M`@````(``````````@`"``````````$``0`!``$``@`!``$``0````$``@`!
M``$``@`!``$``@`!``$``0`!``$``0`!``$``0`!`````0`!``$``0`!````
M`0`!``$``0"X`@``$````"`````3:6D-```$`)$%`````````0`#``<#```0
M`````````!1I:0T```4`FP4``!````!R&6D)```#`*4%```0````$VEI#0``
M`@"1!0````````PQ!0@&"```@#(%"`5=``"$,@4(!5<``(@R!0@%;@``(#$%
M"`<!```D,04(!P(``"@Q!0@'`P``+#$%"`<$```P,04(!P4``#0Q!0@'!@``
M.#$%"`<'```\,04(!TP``$`Q!0@'"```1#$%"`<*``!(,04(!PL``$PQ!0@'
M#```4#$%"`<-``!4,04(!PX``%@Q!0@'#P``7#$%"`<0``!@,04(!Q$``&0Q
M!0@'$@``:#$%"`<3``!L,04(!Q0``'`Q!0@'%0``=#$%"`<6``!X,04(!Q<`
M`'PQ!0@'&```@#$%"`<9``"$,04(!QH``(@Q!0@'&P``C#$%"`<<``"0,04(
M!QT``)0Q!0@''@``F#$%"`<?``"<,04(!R```*`Q!0@':```I#$%"`=5``"H
M,04(!R$``*PQ!0@'(@``L#$%"`<C``"T,04(!R0``+@Q!0@')0``O#$%"`<F
M``#`,04(!R<``,0Q!0@'*```R#$%"`<I``#,,04(!RH``-`Q!0@'*P``U#$%
M"`<L``#8,04(!RT``-PQ!0@'+@``X#$%"`<O``#D,04(!S```.@Q!0@',0``
M[#$%"`<R``#P,04(!S,``/0Q!0@'-```^#$%"`<U``#\,04(!S8````R!0@'
M-P``!#(%"`<X```(,@4(!SD```PR!0@'.@``$#(%"`<[```4,@4(!SP``!@R
M!0@'/0``'#(%"`<^```@,@4(!S\``"0R!0@'0```*#(%"`=!```L,@4(!T(`
M`#`R!0@'0P``-#(%"`=$```X,@4(!T4``#PR!0@'1@``0#(%"`='``!$,@4(
M!T@``$@R!0@'20``3#(%"`=*``!0,@4(!TL``%6)Y5.#[`3H`````%N!PVR:
M``"+D_C___^%TG0%Z)X```#H?04``.BH-```6%O)P_\U&#$%"/\E'#$%"```
M``#_)2`Q!0AH`````.G@_____R4D,04(:`@```#IT/____\E*#$%"&@0````
MZ<#_____)2PQ!0AH&````.FP_____R4P,04(:"````#IH/____\E-#$%"&@H
M````Z9#_____)3@Q!0AH,````.F`_____R4\,04(:#@```#I</____\E0#$%
M"&A`````Z6#_____)40Q!0AH2````.E0_____R5(,04(:%````#I0/____\E
M3#$%"&A8````Z3#_____)5`Q!0AH8````.D@_____R54,04(:&@```#I$/__
M__\E6#$%"&AP````Z0#_____)5PQ!0AH>````.GP_O___R5@,04(:(````#I
MX/[___\E9#$%"&B(````Z=#^____)6@Q!0AHD````.G`_O___R5L,04(:)@`
M``#IL/[___\E<#$%"&B@````Z:#^____)70Q!0AHJ````.F0_O___R5X,04(
M:+````#I@/[___\E?#$%"&BX````Z7#^____)8`Q!0AHP````.E@_O___R6$
M,04(:,@```#I4/[___\EB#$%"&C0````Z4#^____)8PQ!0AHV````.DP_O__
M_R60,04(:.````#I(/[___\EE#$%"&CH````Z1#^____)9@Q!0AH\````.D`
M_O___R6<,04(:/@```#I\/W___\EH#$%"&@``0``Z>#]____):0Q!0AH"`$`
M`.G0_?___R6H,04(:!`!``#IP/W___\EK#$%"&@8`0``Z;#]____);`Q!0AH
M(`$``.F@_?___R6T,04(:"@!``#ID/W___\EN#$%"&@P`0``Z8#]____);PQ
M!0AH.`$``.EP_?___R7`,04(:$`!``#I8/W___\EQ#$%"&A(`0``Z5#]____
M)<@Q!0AH4`$``.E`_?___R7,,04(:%@!``#I,/W___\ET#$%"&A@`0``Z2#]
M____)=0Q!0AH:`$``.D0_?___R78,04(:'`!``#I`/W___\EW#$%"&AX`0``
MZ?#\____)>`Q!0AH@`$``.G@_/___R7D,04(:(@!``#IT/S___\EZ#$%"&B0
M`0``Z<#\____)>PQ!0AHF`$``.FP_/___R7P,04(:*`!``#IH/S___\E]#$%
M"&BH`0``Z9#\____)?@Q!0AHL`$``.F`_/___R7\,04(:+@!``#I</S___\E
M`#(%"&C``0``Z6#\____)00R!0AHR`$``.E0_/___R4(,@4(:-`!``#I0/S_
M__\E##(%"&C8`0``Z3#\____)1`R!0AHX`$``.D@_/___R44,@4(:.@!``#I
M$/S___\E&#(%"&CP`0``Z0#\____)1PR!0AH^`$``.GP^____R4@,@4(:``"
M``#IX/O___\E)#(%"&@(`@``Z=#[____)2@R!0AH$`(``.G`^____R4L,@4(
M:!@"``#IL/O___\E,#(%"&@@`@``Z:#[____)30R!0AH*`(``.F0^____R4X
M,@4(:#`"``#I@/O___\E/#(%"&@X`@``Z7#[____)4`R!0AH0`(``.E@^___
M_R5$,@4(:$@"``#I4/O___\E2#(%"&A0`@``Z4#[____)4PR!0AH6`(``.DP
M^____R50,@4(:&`"``#I(/O__P`````Q[5Z)X8/D\%!44F@`RP0(:!#+!`A1
M5FAPM@0(Z*O____TD)"0D)"0D)"0D)"0D)!5B>53@^P$@#V<,@4(`'4_H:`R
M!0B[##`%"('K"#`%",'[`H/K`3G8<QZ-M@````"#P`&CH#(%"/\4A0@P!0BA
MH#(%"#G8<NC&!9PR!0@!@\0$6UW#C70F`(V\)P````!5B>6#[!BA$#`%"(7`
M=!*X`````(7`=`G'!"00,`4(_]#)PY"0D)"0D)"0D)"0D)!5,<")Y5W#B?:-
MO"<`````58GE5HMU"%,/M@Z)\(3)="FAO,T$"(U6`0^V&(GPZPH/M@J#P@&$
MR700.-EU\@^V"HG0@\(!A,EU\%M>7<-FD%4QTHGE5XG'5H/''%.![%`!``"-
MM;3^__^)A:S^__^0BPR7B<B)R\'C&,'H&`G8B<O!XPB!XP``_P#!Z0@)V('A
M`/\```G(B026@\(!@_H0=<Z-E>C^__^-3>B0C70F`(M"[#,",T+4,T+,P<@?
MB4(,@\($.<IUZ(N%K/[__XN5K/[__XL`B=&)A:C^__^+01"+C:C^__^+<@2+
M>@@#A;3^__^+4@S!R1N-C`B9>8):B?")^_?0(?,AT`G8BYVH_O__`<&+A:C^
M___!S@(#E;C^__\A\_?0(?@)V(N=J/[__XV4`IEY@EJ)R,'(&P'"`[V\_O__
MB=#!R!O!RP*-A`>9>8):B<^)A:3^__^)R"'?]]`A\`.UP/[__PGX`X6D_O__
MB=?!R0*)M:3^__^)UB'/]]8AW@G^B[VD_O__`YW$_O__P<H"C;0WF7F"6HFU
ML/[__XG&P<X;`[6P_O__B??!SQN-O#N9>8):B<.)O:3^___WTXG'(=<ARPG[
MB?<#G:3^__\#C<C^___!R`(AQXF-I/[__XGQ]]$AT0GYB[VD_O__`Y7,_O__
MP<X"C8P/F7F"6HF-L/[__XG9P<D;`XVP_O__B<_!SQN-O#J9>8):B=KWTB'"
M`X70_O__B;VD_O__B=\A]PGZB<\#E:3^__^)A:3^__^)R,'+`O?0(=\A\`GX
MB[VD_O__`[74_O__P<D"C80'F7F"6HF%L/[__XN]L/[__XG0P<@;`<>)^,'(
M&XV$!IEY@EJ)UHF%I/[__XG0(<[WT"'8`YW8_O__"?`#A:3^__^)_L'*`HF=
MI/[__XG[(=;WTR'+"?.+M:3^__\#C=S^___!SP*-G!Z9>8):B9VP_O__B</!
MRQL#G;#^__^)WL'.&XVT,9EY@EJ)P??1(=$#E>#^__^)M:3^__^)QB'^"?&)
MW@.-I/[__XF5I/[__XG:P<@"]](AQB'Z"?*+M:3^__\#O>3^___!RP*-E!:9
M>8):B96P_O__B[6P_O__B<K!RAL!UHGRP<H;C907F7F"6HG/B96D_O__B<HA
MW_?2(<(#A>C^__\)^@.5I/[__XGWP<D"B86D_O__B?`AS_?0(=@)^(N]I/[_
M_P.=[/[__\'.`HV$!YEY@EJ)A;#^__^+O;#^__^)T,'(&P''B?C!R!N-A`.9
M>8):B=.)A:3^__^)T"'S]]`AR`.-\/[__PG8`X6D_O__B?O!R@*)C:3^__^)
M^2'3]]$A\0G9BYVD_O__P<\"C8P+F7F"6HF-L/[__XN=L/[__XG!P<D;`[7T
M_O__`<N)V<')&XV,#IEY@EJ)QHF-I/[__XG!(?[WT2'1`Y7X_O__"?$#C:3^
M__^)WL'(`HF5I/[__XG:(<;WTB'Z"?*+M:3^__\#O?S^___!RP*-E!:9>8):
MB96P_O__B[6P_O__B<K!RAL!UHGRP<H;C907F7F"6HG/B96D_O__B<HAW_?2
M(<()^HGW`Y6D_O__P<D"`X4`____(<^)A:3^__^)\/?0(=@)^(N]I/[__\'.
M`@.=!/___XV$!YEY@EJ)]XF%L/[__XG0,<_!R!LQUP.%L/[__XV\.Z'KV6[!
MR@*)P\'+&P.-"/___XT<'XG7,?<QQXV\.:'KV6Z)V<'(`L')&P.U#/___XT,
M#XG',=<QWXV\/J'KV6Z)SL'+`L'.&P.5$/___XTT-XG?,<<QSXV\.J'KV6Z)
M\L')`L'*&P.%%/___XT4%XG/,=\Q]XV\.*'KV6Z)T,'(&P''P<X"B?`#G1C_
M__\QR#'0P<H"C9P#H>O9;HGXP<@;`XT<____C00#B=,Q\S'[C9P9H>O9;HG!
MP<\"P<D;`<N)^0.U(/___S'1,<'!R`*-M`ZAZ]ENB=G!R1L#E23___^-#`Z)
MQC'^,=Z-M#*AZ]ENB<K!RP+!RAL!UHG:`[TH____,<(QRL')`HV\%Z'KV6Z)
M\L'*&P.%+/___XT4%XG/,=\Q]XV\.*'KV6Z)T,'(&P''P<X"B?`#G3#___\Q
MR#'0P<H"C9P#H>O9;HGXP<@;`XTT____C00#B=,Q\S'[C9P9H>O9;HG!P<\"
MP<D;`<N)^0.U./___S'1,<'!R`*-M`ZAZ]ENB=G!R1L#E3S___^-#`Z)QC'^
M,=Z-M#*AZ]ENB<K!RP+!RAL!UHG:`[U`____,<(QRL')`HV\%Z'KV6Z)\L'*
M&P.%1/___XT4%XG/,=\Q]XV\.*'KV6Z)T,'(&P''P<X"B?`#G4C___\QR#'0
MP<H"C9P#H>O9;HGXP<@;`XU,____C00#B=,Q\S'[C9P9H>O9;HG!P<\"P<D;
MC0P+B?L#M5#___\QTS'#`Y54____C;0>H>O9;HG+P<@"P<L;C1P>B<:)E:3^
M__\)_HG"(?HAS@G6BY6D_O__`[U8____P<D"C;0RW+P;CXG:P<H;C106B<Z)
MO:3^__\)QHG/(<<AW@G^B[VD_O__`X5<____P<L"C;0WW+P;CXG?B86D_O__
M"<^)V(FUL/[__XG6P<X;`[6P_O__(=<AR`G'BX6D_O__`XU@____P<H"C;PX
MW+P;CXGPP<@;C00'B=>)C:3^__\)WXG1(=DA]PG/BXVD_O__`YUD____P<X"
MC;PYW+P;CXG!P<D;C0P/B?>)G:3^__\)UXGS(=,AQPG?BYVD_O__`Y5H____
MP<@"C;P[W+P;CXG+P<L;C1P?B<>)E:3^__\)]XG"(?(ASPG7BY6D_O__`[5L
M____P<D"C;PZW+P;CXG:P<H;C107B<^)M:3^__\)QXG.(=\AQ@GWB[6D_O__
MP<L"C;P^W+P;CXG6P<X;`X5P____C30WB=\)SXF%I/[__XG8(=<AR`G'BX6D
M_O__`XUT____P<H"C;PXW+P;CXGPP<@;C00'B=>)C:3^__\)WXG1(=DA]PG/
MBXVD_O__`YUX____P<X"C;PYW+P;CXG!P<D;C0P/B?>)G:3^__\)UXGS(=,A
MQPG?BYVD_O__`Y5\____P<@"C;P[W+P;CXG+P<L;C1P?B<>)E:3^__\)]XG"
M(?(ASPG7BY6D_O__`W6`P<D"C;PZW+P;CXG:P<H;C107B<^)M:3^__\)QXG.
M(<8AWPGWB[6D_O__C;P^W+P;CXG6P<X;`T6$P<L"C30WB=^)A:3^__\)SXG8
M(<@AUPG'BX6D_O__`TV(P<H"C;PXW+P;CXGPP<@;C00'B=>)C:3^__\)WXG1
M(=DA]PG/BXVD_O__`UV,P<X"C;PYW+P;CXG!P<D;C0P/B?>)G:3^__\)UXGS
M(=,AQPG?BYVD_O__`U60P<@"C;P[W+P;CXG+P<L;C1P?B<>)E:3^__\)]XG"
M(?(ASPG7BY6D_O__`W64P<D"C;PZW+P;CXG:P<H;C107B<^)M:3^__\)QXG.
M(=\AQ@GWB[6D_O__`T68P<L"C;P^W+P;CXG6P<X;C30WB=^)A:3^__\)SXG8
M(<@AUPG'BX6D_O__`TV<P<H"C;PXW+P;CXGPP<@;C00'B=>)C:3^__\)WXG1
M(=DA]PG/BXVD_O__`UV@P<X"C;PYW+P;CXG!P<D;`<^)\8F=I/[__PG1B?,A
MTR'!"=F+G:3^___!R`(#5:2-C`O<O!N/B<.)C;#^__^)^3'SP<D;,?L#C;#^
M__^-G!K6P6+*P<\"B<K!RAL!TXGZ`W6H,<(QRL')`HVT%M;!8LJ)VL'*&P-%
MK(T4%HG.,?XQWHVT,-;!8LJ)T,'+`L'(&P'&B=@#?;`QR#'0P<H"C;P'UL%B
MRHGPP<@;`TVTC00'B=<QWS'WC;PYUL%BRHG!P<D;P<X"`<\#7;B)\3'1,<&-
MG`O6P6+*B?G!R`+!R1L#5;R-#`N)PS'S,?N-G!K6P6+*B<K!SP+!RAL!TXGZ
M`W7`,<(QRL')`HVT%M;!8LJ)VL'*&P-%Q(T4%HG.,?XQWHVT,-;!8LJ)T,'+
M`L'(&P'&B=@#?<@QR#'0P<H"C;P'UL%BRHGPP<@;`TW,C00'B=<QWS'WC;PY
MUL%BRHG!P<D;P<X"`<\#7=")\3'1,<&-G`O6P6+*B?G!R`+!R1L#5=2-#`N)
MPS'S,?N-G!K6P6+*B<K!SP+!RAL!TXGZ`W78,<(QRL')`HVT%M;!8LJ)VL'*
M&P-%W(T4%HG.,?XQWHVT,-;!8LJ)T,'+`L'(&P'&B=@#?>`QR#'0P<H"C;P'
MUL%BRHGPP<@;`TWDC00'B=<QWS'WC;PYUL%BRHG!P<X"P<D;`UWHC0P/B?<Q
MUS''C;P[UL%BRHG+P<@"P<L;`U7LC1P?B<<Q]S'/C;PZUL%BRHG:P<H;`=>+
ME:C^__\#5?#!R0*-M!;6P6+*B<HQPC':C106B?[!SAL!\HNUK/[__\'+`HD6
M`7X$`5X(`4X,`480@<10`0``6UY?7<.-M@````"-O"<`````58GE@^PXA<")
M7?2)PXEU^(E]_(E5W'40,<"+7?2+=?B+??R)[%W#D*&`,@4(A<")1>!TY`^V
M`SP]=%V$P(G:=%>#P@$/M@(\/70$A,!U\BG:BT7@BS"%]G2^B5WDB<>)TXVT
M)@````"+1>2)7"0(B30DB40D!.A1[___A<!U!H`\'CUT&X/'!(LWA?9UVF:0
MZX:-M@`````QTNNUC70F`"M]X(M%W,'_`HDXC40>`>EF____C;8`````C;\`
M````58GE@^P8C57TZ#+____)PU6)Y8/L"*%<,@4(@_C_=`C)PXVV`````+C(
MRP0(Z,[___^%P'0:#[8`A,!T$SPP#Y7`#[;`HUPR!0C)PXUT)@`QP.OQC;8`
M````C;\`````58GE5HG&4X/L$(U=].L9D(M%],'@`@,%@#(%"(/`!(L0A=*)
M4/QU](G:B?#HK_[__X7`==N#Q!!;7EW#C70F`%6)Y8/L&,<$)`````#H*O#_
M_XL`B00DZ##N___'1"0$_____XD$).A0[?__QP0D`````.@$\/__BP")!"3H
M"N[__\=$)`@`````QT0D!&"K!`B)!"3H,O#__\G#C70F`%6)Y5.#[!3'!"0`
M````Z,GO__^+`(D$).C/[?__B00DZ&?K__^+`(M8!,<$)`````#HIN___XL`
MB00DZ*SM__^)!"3HY.O__P^V`(A#&,<$)`````#H@N___XL`B00DZ(CM__^)
M!"3H(.O__XL`BU@$QP0D`````.A?[___BP")!"3H9>W__XD$).BMZ___BP`/
MMT`09B7_`6:)0QK'!"0`````Z#/O__^+`(D$).@Y[?__B00DZ-'J__^+`(M8
M!,<$)`````#H$.___XL`B00DZ!;M___'1"0(`````,=$)`11S00(B00DZ%[N
M__^)0QS'!"0`````Z-_N__^+`(D$).CE[/__B00DZ'WJ__^+`(M8!,<$)```
M``#HO.[__XL`B00DZ,+L__^)!"3HVNK__XL`B4,@QP0D`````.B9[O__BP")
M!"3HG^S__XD$).@WZO__BP"+6`3'!"0`````Z';N__^+`(D$).A\[/__B00D
MZ&3M__\QTHL`A<!T(\<$)`````#H4.[__XL`B00DZ%;L__^)!"3H/NW__XL`
MBU!LB5,DQP0D`````.@J[O__BP")!"3H,.S__XD$).C(Z?__BP"+0`3'0"@`
M````QP0D`````.@`[O__BP")!"3H!NS__XD$).B>Z?__BP"+0`3'0"P`````
MQP0D`````.C6[?__BP")!"3HW.O__XD$).ATZ?__BP"+6`3'!"0`````Z+/M
M__^+`(D$).BYZ___B00DZ"'M__^+`(E#,(/$%%M=PXUV`(V\)P````!5B>57
MB<=64X'LG````(7`=`6`.`!U$8'$G````%M>7UW#C;8`````B00DZ/SK__^%
MP(G&=.%FD(DT).@\Z?__A<`/A-````"-6`@/MA73RP0(#[9`"#G0#X3:````
M#[85TLL$"#G0#X3C````B3PDZ/?I__^)'"2)A7#____HZ>G__XN5</___XU$
M`@*)!"3H=^K__XF%=/___XE<)`R)?"0(QT0D!-7+!`B)!"3HR>G__XU%A(E$
M)`B+A73____'!"0#````B40D!.B,[/__@_C_=!0/MT60)0#P```]`$````^$
MCP```(N%=/___XD$).A%Z?__BX5T____B00DZ%?H__^)-"3H;^C__X7`#X4S
M____C78`B30DZ/SK__^)/"3HE.S__X'$G````%M>7UW#D(UT)@`/ME,!.A74
MRP0(#X3P_O__Z1'___^-=@`/MD,!.@73RP0(#X4-____#[9#`CH%U,L$"`^$
MR/[__^GX_O__C78`BX5T____Z'W^___I;____Y"-M"8`````58GE4XG#@^P4
MQP0D`````.CGZ___BP")!"3H[>G__XD$).CEZO__B5PD!,<$)`,```")1"0(
MZ"'J__^%P'0)@\04,<!;7<.0QP0D`````.BHZ___BP")!"3HKNG__XD$).BF
MZO__#[=`#"4`\```/0!```!T+L<$)`````#H>NO__XL`B00DZ(#I__^)!"3H
M>.K__P^W0`PE`/```#T`H```=9N)'"3'1"0$`@```.A(Y___A<`/E,"#Q!0/
MML!;7<.-M"8`````C;PG`````%6)Y5=6B<93,<"#[#R)TX`Z/0^4P`'#B1PD
MZ.WG__^-5>2)QXGPZ&7Y__^%P'0QB00DB470Z-+G__\QR8M5T#G'#X=U`0``
MD`^V!`N(!`J#P0&$P'7R@\0\,<!;7E]=PZ&`,@4(,=*Y"````(,X`'08C;0F
M`````(/"`8L,D(7)=?:-#)4(````@SW`,@4(`'0NB4PD!(D$)(E5T.C+YO__
MA<")P:.`,@4(BU70#X47`0``@\0\N/____];7E]=PXD,),<%P#(%"`$```")
M5=#HU^?__XM5T(7`B<%TU8T$E0````")1=2)1"0(H8`R!0B)#"2)1"0$B4W,
MZ,SE__^+3<R)#8`R!0B+5=#'1)$$`````(E5Y`^V%H#Z/0^$M@```(32B?!U
M"^FK````9I"$TG0.@\`!#[80@/H]C78`=>XI\(M5U(U$.`(#%8`R!0B)!"2)
M5=#H4.?__XM5T(7`B0(/A$K___^+5>2A@#(%"(L$D`^V%H32B!!T)(#Z/70?
M@\8!ZPN0@/H]D(UT)@!T#P^V%H/``8/&`832B!!UY\8`/3'29I`/M@P3B$P0
M`8/"`83)=?'IFO[__XM%Y,'@`HE%U.E-____C025`````(E%U.DS____,<#I
M9/___U6)Y5>_Y<L$"%93N]O+!`B#[&R-==C'1=#ERP0(QT74V\L$",=%V.C+
M!`C'1=S>RP0(QT7@X\L$",=%Y%'-!`CK*HVV`````(M%"(D4)(E5O(E$)`3H
MHNC__X7`=#J`.P!T*HL&B=^#Q@2)PXGXZ/WW__^%P(G"=`6`.`!URHM5"(GX
MZ)C]__^`.P!UUH/$;%M>7UW#C78`BTT(B0PDZ(GE__^)1<2AP,T$"(D$).AY
MY?__BU6\B10DB47`Z&OE__^+3<")1;2+1<2-3`@!BT6T`<B)!"3H\>7__XM5
MO,=$)`0`S00(B50D$(G!H<#-!`B)#"2)3;R)1"0,BT4(B40D".@UY?__BTV\
MB?B)RN@-_?__Z4;___^0C;0F`````%6)Y5=6@^PP9:$4````B47T,<"AF,T$
M"(E%TJ&<S00(B476H:#-!`B)1=JAI,T$"(E%WJ&HS00(B47BH:S-!`B)1>:A
ML,T$"(E%ZJ&TS00(B47N#[<%N,T$"&:)1?*X]<L$".A(]___N/[+!`CH/O?_
M_[@&S`0(Z#3W__^X#\P$".@J]___N!;,!`CH(/?__[@FS`0(Z!;W__^X,LP$
M".@,]___N,C+!`CH`O?__[@[S`0(Z/CV__^X1<P$".CN]O__N$_,!`CHY/;_
M_[A<S`0(Z-KV__^X9<P$".C0]O__N'#,!`CH9O;__X7`=`R)PK@[S`0(Z`;\
M__^X@<P$".A,]O__A<!T#(G"N)/,!`CH[/O__[B>S`0(Z#+V__^%P'0NB<*X
M,LP$".C2^___NLK,!`BX%LP$".C#^___BT7T93,%%````'5'@\0P7E]=P[BN
MS`0(Z/;U__^%P'02B<*XR,L$".B6^___Z\*-="8`C77CO[_,!`BY"@```/.F
M=:V-5>VXR,L$".AR^___ZY[H5^7__XUT)@"-O"<`````58GE@^P8Z-'D__^)
M!"3HB>/__XG",<"%TG0"BP+)PY!5B>564X/L$(M="(7;=&&`.P!T7(D<).@P
MX___C40#_SG##X/=````BS6\S00(#[8(#[86.-%T#.M:C;8`````.`AU4(/H
M`3G#<O4YV(UV`'56#[8`.@8/A(L```")=0B#Q!!;7EWIX>3__Y"-="8`QP0D
M`@```.APX___A<!T!6;'`"X`@\006UY=PXUT)@`X$'2W@^@!.<-R]3G8C78`
M=+"-M@````"#Z`$YPW,'#[80.A9T\HG",<`IVHU*`H'Y``0``'>^@\(!B50D
M"(E<)`3'!"3@,@4(Z'[E__^XX#(%".N@C78`QP0D`@```.CXXO__B<(QP(72
M=(EFQP(N`(G0ZX"+-;S-!`CI.____U6)Y5=64X/L'(MU"(DT).C<_O__#[8(
MB<>)PX3)="NAO,T$"(U7`0^V`.L.C70F``^V"H/"`83)=!`XP77R#[8*B=.#
MP@&$R77PZ$'T__^%P'0=A?9T&8`^`'04QT0D!,S,!`B)'"3HH.3__SG8=`B#
MQ!Q;7E]=PX/$'(GP6UY?7>E*]___C78`C;PG`````%6)Y8/D\%93@^PXC440
MB40D"(U%#(E$)`2-10B)!"3HB.3__\=$)`A,EP0(QT0D!$R7!`C'!"3LF`0(
MZ``4``#'!"0`````Z+#A__^`.`!U.^B6X?__A<"CX#8%"`^$L0$``(D$).@Q
MXO__QP0D`````.A5Y/__BP")!"3H6^+__XD$).B#X___Q@``QP0D`````#';
MZ#+D__^+`(D$).@XXO__B00DZ##D__^`"`+'!"0`````Z!'D__^+`(D$).@7
MXO__B00DZ`_D__^`"`&+50B)7"0L@\(%B50D*-]L)"C8!>#.!`C=!>C.!`C9
MR=KIW^">#X<%`0``P>("B10DZ";C__^+=0RC[#8%"(L6QT`$T<P$",=`"`#/
M!`C'0`S4S`0(B1"+70C'!>@V!0@$````@_L!?A6Z`0```&:0BPR6B4R0#(/"
M`3G3?_*#PP/'!)@`````B40D#*'@-@4(B5PD",=$)!``````QT0D!$#*!`B)
M!"3H+]___X7`B<-T/:'@-@4(B00DZ,SA__^X)LP$".A6\O__A<!T.J'@-@4(
MB00DZ.'>___H?.#__X/$.(G86UZ)[%W#D(UT)@"AX#8%"(D$).B?W___B</K
MLHVT)@````"AY#8%"(7`=`J)!"3HA_W__^NSN#+,!`CH^_'__X7`H^0V!0AT
MH.OAQT0D!(@R!0C'!"38RP0(Z.CA___'!"0!````Z"S?__]5B>575E.![$P$
M``"+10AEBQ44````B57D,=*+=0R)A=3[__^X,LP$".BB\?__BQV\S00(B5PD
M!(G'BX74^___B00DZ!3B__^%P'0QBY74^___N$_,!`CH)/?__XM5Y&4S%10`
M``"+A=3[__\/A9H!``"!Q$P$``!;7E]=PXN5U/O__XD4).@!W___B30DB870
M^___H<#-!`B)1"0$Z/K?__^%P(G&=*2+E=#[__^#P@&)E=#[__^0@#X`=06^
MT\L$"(7_=!2)="0$B3PDZ*K@__^%P`^$RP```(DT).BJWO__#[94!O\Z$W47
MC10&9I`/MDK^@^@!QD+_`(/J`3H+=.X#A=#[__\]_P,```^/.?___XN5U/O_
M_XV%Y/O__XE<)`R)="0(QT0D!`#-!`B)5"00B00DZ&'>___'!"0`````Z&7A
M__^+`(D$).AKW___B00DZ&/@__^-E>3[__^)5"0$QP0D`P```(E$)`CH">'_
M_X7`=2['!"0`````Z"GA__^+`(D$).@OW___B00DZ"?@__\/MT`,)0#P```]
M`(```'0DH<#-!`C'!"0`````B40D!.CBWO__A<")Q@^%]/[__^F#_O__C87D
M^___QT0D!`$```")!"3HS=S__X7`=<*-E>3[__^X3\P$".B-]?__C97D^___
MB10DZ(O?__^)A=3[___I4/[__^A;W___ZPV0D)"0D)"0D)"0D)"058GE5U93
M@>R<@0``BT4(98L5%````(E5Y#'2QX4H?___U\P$",>%+'___]_,!`B)A:!^
M__^X,LP$",>%,'___]/+!`C'A31___]1S00(QX40?___D\P$",>%%'___XS,
M!`C'A1A____DS`0(QX4<?___VLP$",>%('___^S,!`C'A21___]1S00(QX4X
M?___\,P$",>%/'____7,!`C'A4!___]1S00(Z`/O__^%P'0)@#@`#X7F`P``
MC;8`````Z#OY__^%P(G'#X3Y`P``#[8?A-MT(N@AW?__B?J-=@"+"`^^V_8$
M60AU`\8"7X/"`0^V&H3;=>B-G11___^XD\P$".L1C78`BP.#PP2`.``/A$H#
M``#HE>[__X7`B<9TY^AJ\___A<!TWHDT).@ZWO__A<!TTHG&B30DZ"S<__^)
M/"2)P^@BW/__C90#!`0``(D4)(F5E'[__^BMW/__BY64?O__B10DB</HG=S_
M_XL-O,T$"(E\)!3'1"00S,P$"(ET)`B)3"0,QT0D!/[,!`B)A:1^__^)!"3H
MW=O__XN]I'[__\=$)`3``0``B3PDZ"?>__^#^/]U$.A=V___BP"#^!$/A40#
M``"+C:1^__^-A:Q^__^)1"0(QP0D`P```(E,)`3H`MW__X/X_P^$WP<```^W
MA;A^__\E`/```#T`0```#X7^`0``B[7`?O__Z,?<__\YQ@^%ZP$```^WA;A^
M__\E_P$``#W``0``#X74`0``N-[+!`CH<NW__X7`#X2[`@``B00DZ![=__^+
ME:!^__^)1"0$BP*)!"3H?OO__X7`B<(/A)4"``")%"2)E91^___H\MK__XN5
ME'[__X/X`XF%G'[__WYUC70"_+\'S00(N04```#SIG5C@[V<?O__!'05B[V<
M?O__BPV\S00(#[9$.OLZ`75%B[V@?O__BW\$A?^)O9Q^__]T,HD\)(F5E'[_
M_^B0VO__BY64?O__@_@#=AF-=`?\N04```"_#,T$"/.F=`V-M"8`````B96<
M?O__B9V@?O__Z*_L__^%P'4DBX6<?O__QT0D!`````")!"3HX=O__X7`B86<
M?O__#X44`@``NLK,!`BXR,L$".@8\O__,?;H7=S__XN5I'[__\=$)!11S00(
MQT0D!"7-!`B)'"2)5"0(B40D$*&\S00(B40D#.C^V?__B[VD?O__ZT)FD.B/
MV?__@S@1=4OH%=S__XL-O,T$"(/&`<=$)!A1S00(B70D%(E\)`B)3"0,QT0D
M!#/-!`B)1"00B1PDZ+39___'1"0$P`$``(D<).@$W/__@_C_=*N+O:1^__^)
M/"3H<=C__XG:N#+,!`CH:?'__XD<).A!\___ZSR-M"8`````BXVD?O__B[V@
M?O__B4PD#(L'QT0D!#C.!`B)1"0(H80R!0B)!"3HZ=G__\>%H'[__P````"+
M5>1E,Q44````BX6@?O__#X5+!@``@<2<@0``6UY?7<-FD(VU+'___[O7S`0(
MZPV-=@"+'H/&!(`[`'0;B=CH#_#__S'2A<!TZ8D<).C=VO__A<")PG3;B=;I
MG/S__XUT)@")!"2)A91^___HDO+__XN%E'[__XD$).BPVO__B86@?O__Z7;_
M__^0C9T\?___N/#,!`B0C70F`.C3ZO__A<!T#(D$).B#VO__A<!U68L#@\,$
M@#@`=>&_1,T$".GW^___BXV@?O__BQ'I7OW__XN5H'[__XE$)!")?"0,BP+'
M1"0$Q,T$"(E$)`BAA#(%"(D$).CEV/__QX6@?O__`````.GW_O__B<?I@OO_
M_\=$)`P"````QT0D!.[____'1"0(_____XD$).C_V/__BXV<?O__C95$?___
MQT0D"`8```")5"0$B0PDZ&_9__^`O41___\`=0V`O45___]##X1T!```BX6<
M?O__QT0D#`````#'1"0$`````,=$)`@`````B00DZ*/8__^-E6#____'A43_
M__\!(T5GQX5(____B:O-[\>%3/____[<NIC'A5#___]V5#(0QX54____\.'2
MP\>%6/___P````#'A5S___\`````QT6@`````(F5A'[__XF=F'[__XN5G'[_
M_XV%1'___\=$)`@`@```B40D!(D4).BTV/__A<")PP^.<0$``(N-6/___XV]
M1'___XN%7/___XT4V3G*@]``B85<____B=C!Z!T!A5S___^+1:")E5C___^%
MP'16ND````")WRG".=-^`HG7C8U@____C00!C95$?___B7PD"(E4)`2)!"3H
MQ-C__XM%H`'X@_A`B46@#X5?____C8U$?___*?N-A43___^-/#GH,=O__Y"#
M^S\/CKP````Q]I"-="8`BP0WB85@____BT0W!(F%9/___XM$-PB)A6C___^+
M1#<,B85L____BT0W$(F%</___XM$-Q2)A73___^+1#<8B85X____BT0W'(F%
M?/___XM$-R")18"+1#<DB46$BT0W*(E%B(M$-RR)18R+1#<PB460BT0W-(E%
ME(M$-SB)19B+1#<\@\9`B46<C85$____Z(O:__^)V"GP@_@_#X]>____@^M`
MB=C!Z`:)PL'B!HU\.D`ITXE\)`2-O6#___^)7"0(B3PDZ,'7__^)7:#I9?[_
M_XN-G'[__XN=F'[__XD,).A5V/__B[58____BY5<____B?#!Z`.#X#_&A`5@
M____@(/``8/X.`^/A`$``+DX````C;U@____*<&-!`>)E91^__^)3"0(QT0D
M!`````")!"3H8];__XN5E'[__XG0P>@8B$68B=#!Z!"(19F)T,'H"(A%FHGP
MP>@8B$6<B?#!Z!"(19V)\,'H"(A%GHGP,?:(19^-A43___^(59N-?:?HF=G_
M_XN51/___XG1P>D8B<B(3=")T<'I$(A-T8G1B%73BY5(____P>D(B$W2B='!
MZ1B(3=2)T<'I$(A-U8G1B%77BY5,____P>D(B$W6B='!Z1B(3=B)T<'I$(A-
MV8G1B%7;BY50____P>D(B$W:B='!Z1B(3=R)T<'I$(A-W8G1B%7?BY54____
MP>D(B$W>B='!Z1B(3>")T<'I$(A-X8G1P>D(B$WBB%7CZP4/MD0UT`^VP(/&
M`8D\)(/'`HE$)`C'1"0$(,T$".@ZU/__@_X4==G&1<\`C56GQT0D%%'-!`B+
M#;S-!`B+O:1^__^)5"00QT0D!!'-!`B)3"0,B7PD"(D<).C^T___Z5KZ__^-
MO6#___^Y0````"G!C00'B4PD"(F5E'[__\=$)`0`````B00DZ-_4__^-A43_
M___H6-C__XN]A'[__[D.````,<#SJXN5E'[__^E=_O__Z$73__^+O:1^__^+
ME:!^__^+`(E\)`R)1"00BP+'1"0$`,X$"(E$)`BAA#(%"(D$).@4U/__QX6@
M?O__`````.DF^O__@+U&?___00^%?_O__X"]1W___T,/A7+[__^`O4A___](
M#X5E^___@+U)?___10^%6/O__XN]G'[__\=$)`P"````QT0D!,;____'1"0(
M_____XD\).C[T___C85$?___QT0D""D```")1"0$B3PDZ''4__^-E41____'
M1"044<T$".FX_O__Z*G4__^-M@````"-O"<`````58GE5U93@^PLQP0D````
M`.C'U?__BP")!"3HS=/__XD$).@%T___Q@`!N!;,!`CHS.3__X7`=`F`.#$/
MA!<#``"-M"8`````Z&/M___'!"0`````Z(/5__^+`(D$).B)T___QT0D#`L`
M``#'1"0(`0```,=$)`1+S00(B00DZ"G2__^%P`^$W0```(M`##'VNP$```"+
M0!B)1>2AZ#8%"(/X`7\ZZ;,```"-M@````"+1PR+%>PV!0B+%)J)1"0$B10D
MZ.33__^%P`^%B````*'H-@4(@\,!@\8!.=A^?L<$)`````#H\=3__XL`B00D
MZ/?2__^+5>3'1"0,`````(ET)`B)5"0$B00DZ`S3__^%P'1$BSCV1PD$=93'
M!"0`````Z+34__^+`(D$).BZTO__QT0D#`(```#'1"0(`````(E\)`2)!"3H
M[M3__^E@____D(UT)@"AZ#8%"(U0_SGR#X2``0``QP0D`````.AHU/__BP")
M!"3H;M+__\=$)`P%````QT0D"`$```#'1"0$4,T$"(D$).@.T?__A<")PW0^
MBT`,BS#'!"0`````Z"?4__^+`(D$).@MTO__QT0D"%+-!`B)="0$B00DZ`G1
M__^+0PR+&/9#"D`/A4X!``#'!"0`````Z.[3__^+`(D$).CTT?__QT0D#`4`
M``#'1"0(`0```,=$)`1NS`0(B00DZ)30__^%P(G#=#^X3\P$".C8XO__A<")
MQ@^$/@$``(M##(LXQP0D`````.B9T___BP")!"3HG]'__XET)`B)?"0$B00D
MZ'_0___'!"0`````Z'/3__^+`(D$).AYT?__B00DZ+'0___&``#'!"0`````
MZ%+3__^+`(D$).A8T?__B00DZ&#3___'``````"X,LP$".A4XO__A<"CY#8%
M"`^$[@```,=$)`3M`0``B00DZ&/2__^#^!%T#87`=`F#^/\/A3$!``"#Q"Q;
M7E]=PY"-="8`@_@!#XYW_O__NP$```!FD,<$)`````"#PP'HU=+__XL`B00D
MZ-O0__^+5>2)5"0$B00DZ'S/__\Y'>@V!0A_T.D[_O__C78`QP0D`````.B@
MTO__BP")!"3HIM#__XE<)`2)!"3H.M'__^F+_O__D(!X`0`/A.O\__^-M@``
M``#IU/S__XUV`*'L-@4(BSB+0PR+,,<$)`````#H5-+__XL`B00DZ%K0__^)
M?"0(B70D!(D$).@ZS___Z;;^__^A[#8%"(D$).B<\?__BSWL-@4(H^0V!0B+
M0PR+,/9&"00/A)8```"+1@R)?"0$B00DZ!_0__^)QHM##(L8]D,)!'1&BT,,
MB40D"*'L-@4(B70D#(L`QP0D8,X$"(E$)`3H`-'__XE$)`RAY#8%"(E$)`BA
M[#8%"(L`QP0DD,X$"(E$)`3HW-#__\<$)`````#HH-'__XL`B00DZ*;/___'
M1"0,`@```,=$)`@`````B5PD!(D$).C:T?__ZXG'!"0`````Z&S1__^+`(D$
M).ARS___QT0D#`(```#'1"0(`````(ET)`2)!"3HIM'__^DV____D(UT)@!5
MB>6#[!C'!"0`````Z"K1__^+`(D$).@PS___QT0D#%?-!`C'1"0(W)@$",=$
M)`1AS00(B00DZ,#0___)PV:058GE@^PHQP0D`````.CJT/__BP")!"3H\,[_
M_XD$).B<____QP0D`````.C,T/__BP")!"3HTL[__\=$)!0`````QT0D$%'-
M!`C'1"0,4<T$",=$)`A@Q00(QT0D!'W-!`B)!"3H4L[__\G#D)"0D%6)Y5/H
M.````('#6V8``(/L$(N#_/___X7`=`*+`(E$)`R+11")1"0(BT4,B40D!(M%
M"(D$).C!S/__@\006UW#BQPDPY"0D)"0D)"0D)"058GE7<.-="8`C;PG````
M`%6)Y5=64^C6____@</Y90``@^P<Z'/+__^-N^S^__^-@^S^__\IQ\'_`H7_
M="0Q]HM%$(E$)`B+10R)1"0$BT4(B00D_Y2S[/[__X/&`3G^<MZ#Q!Q;7E]=
MPY"0D)"0D%6)Y5.#[`2A`#`%"(/X_W03NP`P!0AFD(/K!/_0BP.#^/]U](/$
M!%M=PY"058GE4X/L!.@`````6X'#;&4``.@LT/__65O)PP```````````P``
M``$``@!005)?0TQ%04X`+BX`)7,O)7,`3$E"4$%42`!$64Q$7TQ)0E)!4EE?
M4$%42`!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)
M5$E!3$E:140`4$%27U-005=.140`4$%27U1%35``4$%27T1%0E5'`%!!4E]#
M04-(10!005)?4%)/1TY!344`4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/
M0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`'!A<BT`
M+64`+2T`0SI<5$5-4``O=&UP`%1%35!$25(`5$U0`%5315(`55-%4DY!344`
M)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"4P,G@`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`%-94U1%30!!4D=6`!@`<&5R;`!P
M97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L
M<SHZ4$%2.CI"3T]4`"\`.@```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@`````)+-!`B4S00()7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('-T870@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E"@``)7,Z(&5X
M96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`````````````````@/__
M_\]!<&%R+G!L`````````````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P
M;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE
M<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U
M.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M
M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I
M;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS
M=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@
M("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER
M(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@
M("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE
M=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E
M8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P
M;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@
M("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S
M92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C
M;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T
M:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7
M:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@
M("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@
M(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@
M/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I
M.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@
M9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@
M+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W
M,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I
M;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@
M)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*
M"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN
M:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%
M3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?
M05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@
M/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%
M3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F
M:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@
M/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*
M7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T
M<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@
M>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP
M92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(
M+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*
M("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M
M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@
M,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT
M96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C
M:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*
M("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@
M("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@
M("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@
M("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L
M("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@
M("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@
M)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@
M("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V
M960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@
M(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M
M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*
M("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@
M("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@
M("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U
M;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.
M0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*
M("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@
M("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@
M("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@
M("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y
M*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@
M<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N
M86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@
M("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E
M*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M
M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D
M:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@
M<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P
M<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@
M0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*
M"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@
M("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*
M("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R
M;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R
M97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D
M=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@
M(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@
M<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R
M;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2
M155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R
M;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@
M1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B
M;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@
M(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@
M("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?
M<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P
M87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P
M<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'
M5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C
M;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET
M<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N
M;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?
M=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D
M05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T
M.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@
M("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A
M;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G
M<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@
M("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U
M;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@
M("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B
M6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D
M8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S
M:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@
M("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@
M("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@
M("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!8
M6%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P
M=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@
M("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@
M("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN
M960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@
M9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E
M*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@
M("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E
M<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@
M(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@
M("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*
M("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM[
M"B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*
M("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B
M.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@
M;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"([
M"B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D
M(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A
M7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@
M,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L
M;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE
M>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y
M*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H
M)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D
M9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]
M"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U
M;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I
M;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY
M($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N
M9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.
M+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S
M:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C
M($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@
M("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T
M;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4
M:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F
M('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O
M=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN
M9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@
M)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL
M97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F
M;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@
M("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@
M(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@
M("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<
M15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I
M;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H
M;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E
M;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE
M?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I
M;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q
M*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N
M=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@
M("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C
M;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*
M"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A
M9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@
M("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO
M9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I
M(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@
M("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F
M:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@
M("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@
M3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@
M("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@
M("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@
M(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@
M9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X
M+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@
M)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I
M.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@
M("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T
M,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B
M0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI
M*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO
M<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET
M.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@
M8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O
M<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@
M4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@
M("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER
M92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@
M("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A
M8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H
M<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@
M(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@
M("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*
M("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@
M(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@
M("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@
M("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I
M;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@
M?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@
M("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T
M:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H
M+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E
M<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB
M.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R
M.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@
M("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER
M92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R
M97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q
M=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E
M<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q
M=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@
M("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@
M<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@
M("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@
M871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A
M;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PH@("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES
M(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E
M(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP
M7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@
M("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*
M"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@
M(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W
M=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@
M("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*
M("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S
M=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92([
M"B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@
M("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F
M:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L
M(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@
M("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@
M("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!
M,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@
M("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N
M,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@
M("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M
M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@
M("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@
M("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@
M("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@
M?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@
M("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA
M;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*
M("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I
M;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE
M+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@
M*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*
M("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B
M:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC
M('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P
M<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D
M<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@
M("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F
M:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG
M>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?
M97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@
M("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@
M("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@
M("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@
M("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@
M(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K
M"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ
M9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP
M*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N
M=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?
M,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]
M"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@
M("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@
M("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D
M96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES
M=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>
M4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T
M=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN
M="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I
M;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER
M92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E
M>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N
M;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q
M,#$R"@I?7T5.1%]?"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#_____`````/____\```````````$````!`````0```*,"
M```!````K@(```$```"X`@```0````<#```!````+@0```P```"<E@0(#0``
M`)S+!`@$````:($$"/7^_V^XA`0(!0```""-!`@&````$(8$"`H```"Q!0``
M"P```!`````5``````````,````4,04(`@```&@"```4````$0```!<````T
ME`0($0```!24!`@2````(````!,````(````_O__;[23!`C___]O`@```/#_
M_V_2D@0(````````````````````````````````````````````````````
M`````````````````%@R!0@4,`4(``````````#BE@0(\I8$"`*7!`@2EP0(
M(I<$"#*7!`A"EP0(4I<$"&*7!`AREP0(@I<$")*7!`BBEP0(LI<$",*7!`C2
MEP0(XI<$"/*7!`@"F`0($I@$""*8!`@RF`0(0I@$"%*8!`ABF`0(<I@$"(*8
M!`B2F`0(HI@$"+*8!`C"F`0(TI@$".*8!`CRF`0(`ID$"!*9!`@BF00(,ID$
M"$*9!`A2F00(8ID$"'*9!`B"F00(DID$"**9!`BRF00(PID$"-*9!`CBF00(
M\ID$"`*:!`@2F@0((IH$"#*:!`A"F@0(4IH$"&*:!`ARF@0(@IH$")*:!`BB
MF@0(LIH$",*:!`C2F@0(XIH$"/*:!`@"FP0($IL$""*;!`@RFP0(0IL$"%*;
M!`ABFP0(<IL$"(*;!`B2FP0(HIL$"```````````______#.!`CI6P``1T-#
M.B`H1&5B:6%N(#0N-"XU+3@I(#0N-"XU```N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F
M<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L
M=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````
M``````````````````````````L````!`````@```!2!!`@4`0``#0``````
M`````````0`````````3````!P````(````D@00()`$``"``````````````
M``0`````````(0````<````"````1($$"$0!```D```````````````$````
M`````#@````%`````@```&B!!`AH`0``4`,```8`````````!`````0````T
M````]O__;P(```"XA`0(N`0``%@!```&``````````0````$````/@````L`
M```"````$(8$"!`&```0!P``!P````$````$````$````$8````#`````@``
M`""-!`@@#0``L04``````````````0````````!.````____;P(```#2D@0(
MTA(``.(````&``````````(````"````6P```/[__V\"````M),$"+03``!@
M````!P````(````$`````````&H````)`````@```!24!`@4%```(`````8`
M````````!`````@```!S````"0````(````TE`0(-!0``&@"```&````#0``
M``0````(````?`````$````&````G)8$")P6```P```````````````$````
M`````'<````!````!@```,R6!`C,%@``X`0`````````````!`````0```""
M`````0````8```"PFP0(L!L``.PO`````````````!``````````B`````$`
M```&````G,L$")Q+```<```````````````$`````````(X````!`````@``
M`,#+!`C`2P``*E\`````````````(`````````"6`````0````(```#L*@4(
M[*H```0```````````````0`````````H`````$````#`````#`%"`"P```(
M```````````````$`````````*<````!`````P````@P!0@(L```"```````
M````````!`````````"N`````0````,````0,`4($+````0`````````````
M``0`````````LP````8````#````%#`%"!2P``#X````!P`````````$````
M"````+P````!`````P````PQ!0@,L0``"```````````````!`````0```#!
M`````0````,````4,04(%+$``$`!``````````````0````$````R@````$`
M```#````5#(%"%2R```4```````````````$`````````-`````(`````P``
M`(`R!0AHL@``<`0`````````````(`````````#5`````0```#``````````
M:+(``!P```````````````$````!`````0````,``````````````(2R``#>
3```````````````!````````````
